Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(141)

Unified Diff: tools/skpdiff/SkImageDiffer.h

Issue 325413003: rebaseline_server: use just skpdiff, not Python Image Library (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tools/skpdiff/SkImageDiffer.h
diff --git a/tools/skpdiff/SkImageDiffer.h b/tools/skpdiff/SkImageDiffer.h
index 641bbe8f8f863b4610348b5b41573564e21fc88b..63db05e49c6e3baef1af4a6e5f58d5879af70649 100644
--- a/tools/skpdiff/SkImageDiffer.h
+++ b/tools/skpdiff/SkImageDiffer.h
@@ -25,6 +25,11 @@ public:
double result;
int poiCount;
SkBitmap poiAlphaMask; // optional
+ SkBitmap rgbDiffBitmap; // optional
+ SkBitmap whiteDiffBitmap; // optional
+ int maxRedDiff; // optional
+ int maxGreenDiff; // optional
+ int maxBlueDiff; // optional
double timeElapsed; // optional
};
@@ -43,11 +48,13 @@ public:
* diff on a pair of bitmaps.
* @param baseline The correct bitmap
* @param test The bitmap whose difference is being tested
* @param computeMask true if the differ is to attempt to create poiAlphaMask
* @return true on success, and false in the case of failure
*/
- virtual bool diff(SkBitmap* baseline, SkBitmap* test, bool computeMask,
- Result* result) const = 0;
+ virtual bool diff(SkBitmap* baseline, SkBitmap* test, bool computeAlphaMask,
+ bool computeRgbDiff, bool computeWhiteDiff, Result* result) const = 0;
};
#endif
@@ -43,11 +48,13 @@ public:
* @param baseline The correct bitmap
* @param test The bitmap whose difference is being tested
- * @param computeMask true if the differ is to attempt to create poiAlphaMask
+ * @param computeAlphaMask true if the differ is to attempt to create poiAlphaMask
+ * @param computeRgbDiff true if the differ is to attempt to create rgbDiffBitmap
+ * @param computeWhiteDiff true if the differ is to attempt to create whiteDiffBitmap
* @return true on success, and false in the case of failure
*/

Powered by Google App Engine
This is Rietveld 408576698